import { join } from 'path';
import { existsSync, statSync, readFileSync, mkdirSync, writeFileSync } from 'fs';
import { resolve } from 'node:path';
import { appendFile } from 'node:fs';

/**
 *
 * @returns {string}
 */
function getRootPath() {
  return process.cwd();
}

var defaultConfig = {
  creatingDir: 'src',
  useTypescript: true,
  useCssPreprocessors: 'css'
};

var dirSuffix = {
  components: '',
  icons: 'Icon'
};
var defaultTemplate = {
  components: function components(componentName, config) {
    return [{
      fileName: "" + componentName + dirSuffix.components + "." + (config.useTypescript ? 't' : 'j') + "sx",
      template: "import React from \"react\";\n\nimport style from \"./" + componentName + dirSuffix.components + ".module." + config.useCssPreprocessors + "\";\n\n" + (config.useTypescript ? "export interface " + componentName + "Props {}" : '') + "\n\nexport const " + componentName + " = ({}: " + componentName + "Props) => {\n  return <div className={style.root}></div>;\n};\n"
    }, {
      fileName: "index." + (config.useTypescript ? 't' : 'j') + "s",
      template: "export * from \"./" + componentName + dirSuffix.components + "\";\n"
    }, {
      fileName: "" + componentName + dirSuffix.components + ".module." + config.useCssPreprocessors,
      template: ".root {}\n"
    }];
  }
};

function getConfig() {
  var patch = join(getRootPath(), 'ks-cli.config.json');
  if (!existsSync(patch)) {
    return defaultConfig;
  }
  try {
    var stats = statSync(patch);
    if (stats.isFile()) {
      var data = readFileSync(patch, 'utf8');
      return Object.assign(defaultConfig, JSON.parse(data));
    } else {
      return defaultConfig;
    }
  } catch (error) {
    return defaultConfig;
  }
}

/**
 *
 * @param path
 * @description Создает директорию по переданному пути
 */
function createDir(path) {
  if (!existsSync(path)) {
    mkdirSync(path);
  }
}

function createFile(fileName, template) {
  writeFileSync(fileName, template);
}

var fileTypesArray = ['rc', 'component', 'c'];
function create(props) {
  var sepReg = /\/|\\/;
  var config = getConfig();
  var filePath = props.filePath,
    fileType = props.fileType;
  var pathArray = filePath.split(sepReg);
  var fileName = pathArray.at(-1);
  if (!fileTypesArray.includes(fileType)) {
    console.log('Неверно введен тип создаваемого элемента');
    return false;
  }
  var type = fileType;
  if (fileName) {
    var rootPath = getRootPath();
    var intermediatePath = rootPath;
    var sourcePath = join.apply(void 0, [rootPath, config.creatingDir].concat(pathArray));
    if (existsSync(sourcePath)) {
      console.log('Невозможно создать элемент, данная директория уже существует');
      return false;
    }
    var creatingPathArray = [].concat(config.creatingDir.split(sepReg), pathArray);
    creatingPathArray.forEach(function (el) {
      var path = join(intermediatePath, el);
      createDir(path);
      intermediatePath = path;
    });
    if (type === 'c' || type === 'component' || type === 'rc') {
      defaultTemplate.components(fileName, config).forEach(function (file) {
        createFile(join(sourcePath, file.fileName), file.template);
      });
      console.log('Компонент успешно создан');
      return true;
    }
    return false;
  }
  return false;
}

function generate(type, name) {
  if (type === 'rc' || type === 'c' || type === 'component') {
    var isCreating = create({
      fileType: 'c',
      filePath: 'components/' + name
    });
    if (!isCreating) {
      console.log('Генерация прервана');
      return;
    }
    var path = resolve(getRootPath(), 'src', 'components', 'index.ts');
    var data = "export * from \"./" + name + "\";\n";
    appendFile(path, data, function (err) {
      if (err) throw err;
      console.log('Файл реэкспорта успешно обновлен');
    });
  }
}

function cli() {
  var _process$argv$slice = process.argv.slice(2),
    action = _process$argv$slice[0],
    type = _process$argv$slice[1],
    name = _process$argv$slice[2];
  if ((action === 'create' || action === 'c') && type && name) {
    create({
      filePath: name,
      fileType: type
    });
    return;
  }
  if ((action === 'g' || action === 'generate') && type && name) {
    generate(type, name);
    return;
  }
  console.error('Невозможно выполнить команду');
}
cli();
//# sourceMappingURL=ks-react-cli-lib.esm.js.map
